==> jc-1.4.0.tar.gz: javax/swing/JPopupMenu__24ActionChangeListener.h <==
// public class javax.swing.JPopupMenu$ActionChangeListener

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ef55adb0b6e3363d javax_swing_JPopupMenu__24ActionChangeListener

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_JPopupMenu__24ActionChangeListener_H_
#define _JC_javax_swing_JPopupMenu__24ActionChangeListener_H_

// Forward structure declarations
struct _jc_java_beans_PropertyChangeEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JPopupMenu$object;

// Typedefs
typedef struct _jc_javax_swing_JPopupMenu__24ActionChangeListener$sub_refs	_jc_javax_swing_JPopupMenu__24ActionChangeListener$sub_refs;
typedef struct _jc_javax_swing_JPopupMenu__24ActionChangeListener$sub_nonrefs	_jc_javax_swing_JPopupMenu__24ActionChangeListener$sub_nonrefs;
typedef struct _jc_javax_swing_JPopupMenu__24ActionChangeListener$refs	_jc_javax_swing_JPopupMenu__24ActionChangeListener$refs;
typedef struct _jc_javax_swing_JPopupMenu__24ActionChangeListener$nonrefs	_jc_javax_swing_JPopupMenu__24ActionChangeListener$nonrefs;
typedef struct _jc_javax_swing_JPopupMenu__24ActionChangeListener$object	_jc_javax_swing_JPopupMenu__24ActionChangeListener$object;

typedef const struct _jc_javax_swing_JPopupMenu__24ActionChangeListener$vmethods	_jc_javax_swing_JPopupMenu__24ActionChangeListener$vmethods;
typedef const struct _jc_javax_swing_JPopupMenu__24ActionChangeListener$vtable	_jc_javax_swing_JPopupMenu__24ActionChangeListener$vtable;
typedef const struct _jc_javax_swing_JPopupMenu__24ActionChangeListener$vtype	_jc_javax_swing_JPopupMenu__24ActionChangeListener$vtype;

// Constructors
extern void _jc_javax_swing_JPopupMenu__24ActionChangeListener$method$_init$83d0e0054d3484d1(_jc_env *, struct _jc_javax_swing_JPopupMenu__24ActionChangeListener$object *, struct _jc_javax_swing_JPopupMenu$object *);

// Virtual methods
extern void _jc_javax_swing_JPopupMenu__24ActionChangeListener$method$propertyChange$6d3500eaa79bf44b(_jc_env *, struct _jc_javax_swing_JPopupMenu__24ActionChangeListener$object *, struct _jc_java_beans_PropertyChangeEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JPopupMenu__24ActionChangeListener$method_info$propertyChange$6d3500eaa79bf44b;

// Virtual methods structure
struct _jc_javax_swing_JPopupMenu__24ActionChangeListener$vmethods {
	void	(*propertyChange$6d3500eaa79bf44b)(_jc_env *, struct _jc_javax_swing_JPopupMenu__24ActionChangeListener$object *, struct _jc_java_beans_PropertyChangeEvent$object *);
};

// Vtable
struct _jc_javax_swing_JPopupMenu__24ActionChangeListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_JPopupMenu__24ActionChangeListener$vmethods	javax_swing_JPopupMenu__24ActionChangeListener;
};

// Vtype
struct _jc_javax_swing_JPopupMenu__24ActionChangeListener$vtype {
	_jc_type			type;
	_jc_javax_swing_JPopupMenu__24ActionChangeListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JPopupMenu__24ActionChangeListener$sub_refs {
	struct _jc_javax_swing_JPopupMenu$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JPopupMenu__24ActionChangeListener$refs {
    _jc_javax_swing_JPopupMenu__24ActionChangeListener$sub_refs	javax_swing_JPopupMenu__24ActionChangeListener;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JPopupMenu__24ActionChangeListener$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JPopupMenu__24ActionChangeListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_JPopupMenu__24ActionChangeListener$sub_nonrefs	javax_swing_JPopupMenu__24ActionChangeListener;
};

// Object instance structure
struct _jc_javax_swing_JPopupMenu__24ActionChangeListener$object {
	_jc_javax_swing_JPopupMenu__24ActionChangeListener$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JPopupMenu__24ActionChangeListener$vtype	*vtype;
	_jc_javax_swing_JPopupMenu__24ActionChangeListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JPopupMenu__24ActionChangeListener$vtype _jc_javax_swing_JPopupMenu__24ActionChangeListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JPopupMenu__24ActionChangeListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JPopupMenu__24ActionChangeListener$class_object;

#endif	/* _JC_javax_swing_JPopupMenu__24ActionChangeListener_H_ */

==> jc-1.4.5.tar.gz: javax/swing/JPopupMenu__24ActionChangeListener.h <==
// public class javax.swing.JPopupMenu$ActionChangeListener

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ef55adb0b6e3363d javax_swing_JPopupMenu__24ActionChangeListener

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_JPopupMenu__24ActionChangeListener_H_
#define _JC_javax_swing_JPopupMenu__24ActionChangeListener_H_

// Forward structure declarations
struct _jc_java_beans_PropertyChangeEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JPopupMenu$object;

// Typedefs
typedef struct _jc_javax_swing_JPopupMenu__24ActionChangeListener$sub_refs	_jc_javax_swing_JPopupMenu__24ActionChangeListener$sub_refs;
typedef struct _jc_javax_swing_JPopupMenu__24ActionChangeListener$sub_nonrefs	_jc_javax_swing_JPopupMenu__24ActionChangeListener$sub_nonrefs;
typedef struct _jc_javax_swing_JPopupMenu__24ActionChangeListener$refs	_jc_javax_swing_JPopupMenu__24ActionChangeListener$refs;
typedef struct _jc_javax_swing_JPopupMenu__24ActionChangeListener$nonrefs	_jc_javax_swing_JPopupMenu__24ActionChangeListener$nonrefs;
typedef struct _jc_javax_swing_JPopupMenu__24ActionChangeListener$object	_jc_javax_swing_JPopupMenu__24ActionChangeListener$object;

typedef const struct _jc_javax_swing_JPopupMenu__24ActionChangeListener$vmethods	_jc_javax_swing_JPopupMenu__24ActionChangeListener$vmethods;
typedef const struct _jc_javax_swing_JPopupMenu__24ActionChangeListener$vtable	_jc_javax_swing_JPopupMenu__24ActionChangeListener$vtable;
typedef const struct _jc_javax_swing_JPopupMenu__24ActionChangeListener$vtype	_jc_javax_swing_JPopupMenu__24ActionChangeListener$vtype;

// Constructors
extern void _jc_javax_swing_JPopupMenu__24ActionChangeListener$method$_init$83d0e0054d3484d1(_jc_env *, struct _jc_javax_swing_JPopupMenu__24ActionChangeListener$object *, struct _jc_javax_swing_JPopupMenu$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_JPopupMenu__24ActionChangeListener$method$propertyChange$6d3500eaa79bf44b(_jc_env *, struct _jc_javax_swing_JPopupMenu__24ActionChangeListener$object *, struct _jc_java_beans_PropertyChangeEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JPopupMenu__24ActionChangeListener$method_info$propertyChange$6d3500eaa79bf44b;

// Virtual methods structure
struct _jc_javax_swing_JPopupMenu__24ActionChangeListener$vmethods {
	void	(*propertyChange$6d3500eaa79bf44b)(_jc_env *, struct _jc_javax_swing_JPopupMenu__24ActionChangeListener$object *, struct _jc_java_beans_PropertyChangeEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_JPopupMenu__24ActionChangeListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_JPopupMenu__24ActionChangeListener$vmethods	javax_swing_JPopupMenu__24ActionChangeListener;
};

// Vtype
struct _jc_javax_swing_JPopupMenu__24ActionChangeListener$vtype {
	_jc_type			type;
	_jc_javax_swing_JPopupMenu__24ActionChangeListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JPopupMenu__24ActionChangeListener$sub_refs {
	struct _jc_javax_swing_JPopupMenu$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JPopupMenu__24ActionChangeListener$refs {
    _jc_javax_swing_JPopupMenu__24ActionChangeListener$sub_refs	javax_swing_JPopupMenu__24ActionChangeListener;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JPopupMenu__24ActionChangeListener$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JPopupMenu__24ActionChangeListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_JPopupMenu__24ActionChangeListener$sub_nonrefs	javax_swing_JPopupMenu__24ActionChangeListener;
};

// Object instance structure
struct _jc_javax_swing_JPopupMenu__24ActionChangeListener$object {
	_jc_javax_swing_JPopupMenu__24ActionChangeListener$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JPopupMenu__24ActionChangeListener$vtype	*vtype;
	_jc_javax_swing_JPopupMenu__24ActionChangeListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JPopupMenu__24ActionChangeListener$vtype _jc_javax_swing_JPopupMenu__24ActionChangeListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JPopupMenu__24ActionChangeListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JPopupMenu__24ActionChangeListener$class_object;

#endif	/* _JC_javax_swing_JPopupMenu__24ActionChangeListener_H_ */
